Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(43)

Unified Diff: chrome/browser/chromeos/status/clock_menu_button.cc

Issue 7324017: Split SystemAccess into TimezoneSettings, StatisticsProvider, and SyslogsProvider. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: add a missing include Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/status/clock_menu_button.cc
diff --git a/chrome/browser/chromeos/status/clock_menu_button.cc b/chrome/browser/chromeos/status/clock_menu_button.cc
index a18379286f87d806abce2ed83d1d24906e2c73f2..5880b0ba4d56bc8e20549ad14a307c13def95c11 100644
--- a/chrome/browser/chromeos/status/clock_menu_button.cc
+++ b/chrome/browser/chromeos/status/clock_menu_button.cc
@@ -40,8 +40,8 @@ const int kTimerSlopSeconds = 1;
ClockMenuButton::ClockMenuButton(StatusAreaHost* host)
: StatusAreaButton(host, this) {
- // Add as SystemAccess observer. We update the clock if timezone changes.
- SystemAccess::GetInstance()->AddObserver(this);
+ // Add as TimezoneSettings observer. We update the clock if timezone changes.
+ system::TimezoneSettings::GetInstance()->AddObserver(this);
CrosLibrary::Get()->GetPowerLibrary()->AddObserver(this);
// Start monitoring the kUse24HourClock preference.
if (host->GetProfile()) { // This can be NULL in the login screen.
@@ -54,7 +54,7 @@ ClockMenuButton::ClockMenuButton(StatusAreaHost* host)
ClockMenuButton::~ClockMenuButton() {
CrosLibrary::Get()->GetPowerLibrary()->RemoveObserver(this);
- SystemAccess::GetInstance()->RemoveObserver(this);
+ system::TimezoneSettings::GetInstance()->RemoveObserver(this);
}
void ClockMenuButton::UpdateTextAndSetNextTimer() {

Powered by Google App Engine
This is Rietveld 408576698